@@ -16,27 +16,27 @@
 from collections import OrderedDict
 import os
 import re
-from typing import Dict, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 
 from google.api_core import client_options as client_options_lib
 from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
 from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
+from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
-from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.oauth2 import service_account  # type: ignore
+import pkg_resources
 
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
 except AttributeError:  # pragma: NO COVER
     OptionalRetry = Union[retries.Retry, object]  # type: ignore
 
-from google.cloud.servicecontrol_v1.types import metric_value
-from google.cloud.servicecontrol_v1.types import quota_controller
-from .transports.base import QuotaControllerTransport, DEFAULT_CLIENT_INFO
+from google.cloud.servicecontrol_v1.types import metric_value, quota_controller
+
+from .transports.base import DEFAULT_CLIENT_INFO, QuotaControllerTransport
 from .transports.grpc import QuotaControllerGrpcTransport
 from .transports.grpc_asyncio import QuotaControllerGrpcAsyncIOTransport
 
@@ -55,7 +55,10 @@ class QuotaControllerClientMeta(type):
     _transport_registry["grpc"] = QuotaControllerGrpcTransport
     _transport_registry["grpc_asyncio"] = QuotaControllerGrpcAsyncIOTransport
 
-    def get_transport_class(cls, label: str = None,) -> Type[QuotaControllerTransport]:
+    def get_transport_class(
+        cls,
+        label: str = None,
+    ) -> Type[QuotaControllerTransport]:
         """Returns an appropriate transport class.
 
         Args:
@@ -164,7 +167,9 @@ class QuotaControllerClient(metaclass=QuotaControllerClientMeta):
         return self._transport
 
     @staticmethod
-    def common_billing_account_path(billing_account: str,) -> str:
+    def common_billing_account_path(
+        billing_account: str,
+    ) -> str:
         """Returns a fully-qualified billing_account string."""
         return "billingAccounts/{billing_account}".format(
             billing_account=billing_account,
@@ -177,9 +182,13 @@ class QuotaControllerClient(metaclass=QuotaControllerClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_folder_path(folder: str,) -> str:
+    def common_folder_path(
+        folder: str,
+    ) -> str:
         """Returns a fully-qualified folder string."""
-        return "folders/{folder}".format(folder=folder,)
+        return "folders/{folder}".format(
+            folder=folder,
+        )
 
     @staticmethod
     def parse_common_folder_path(path: str) -> Dict[str, str]:
@@ -188,9 +197,13 @@ class QuotaControllerClient(metaclass=QuotaControllerClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_organization_path(organization: str,) -> str:
+    def common_organization_path(
+        organization: str,
+    ) -> str:
         """Returns a fully-qualified organization string."""
-        return "organizations/{organization}".format(organization=organization,)
+        return "organizations/{organization}".format(
+            organization=organization,
+        )
 
     @staticmethod
     def parse_common_organization_path(path: str) -> Dict[str, str]:
@@ -199,9 +212,13 @@ class QuotaControllerClient(metaclass=QuotaControllerClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_project_path(project: str,) -> str:
+    def common_project_path(
+        project: str,
+    ) -> str:
         """Returns a fully-qualified project string."""
-        return "projects/{project}".format(project=project,)
+        return "projects/{project}".format(
+            project=project,
+        )
 
     @staticmethod
     def parse_common_project_path(path: str) -> Dict[str, str]:
@@ -210,10 +227,14 @@ class QuotaControllerClient(metaclass=QuotaControllerClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_location_path(project: str, location: str,) -> str:
+    def common_location_path(
+        project: str,
+        location: str,
+    ) -> str:
         """Returns a fully-qualified location string."""
         return "projects/{project}/locations/{location}".format(
-            project=project, location=location,
+            project=project,
+            location=location,
         )
 
     @staticmethod
@@ -408,7 +429,6 @@ class QuotaControllerClient(metaclass=QuotaControllerClientMeta):
         inject these errors to prohibit any hard dependency on the quota
         functionality.
 
-
         .. code-block:: python
 
             from google.cloud import servicecontrol_v1
@@ -455,8 +475,21 @@ class QuotaControllerClient(metaclass=QuotaControllerClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.allocate_quota]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (("service_name", request.service_name),)
+            ),
+        )
+
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
