@@ -13,18 +13,21 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-import proto  # type: ignore
-
-from google.cloud.servicecontrol_v1.types import http_request as gas_http_request
 from google.logging.type import log_severity_pb2  # type: ignore
 from google.protobuf import any_pb2  # type: ignore
 from google.protobuf import struct_pb2  # type: ignore
 from google.protobuf import timestamp_pb2  # type: ignore
+import proto  # type: ignore
 
+from google.cloud.servicecontrol_v1.types import http_request as gas_http_request
 
 __protobuf__ = proto.module(
     package="google.api.servicecontrol.v1",
-    manifest={"LogEntry", "LogEntryOperation", "LogEntrySourceLocation",},
+    manifest={
+        "LogEntry",
+        "LogEntryOperation",
+        "LogEntrySourceLocation",
+    },
 )
 
 
@@ -62,7 +65,7 @@ class LogEntry(proto.Message):
             A unique ID for the log entry used for deduplication. If
             omitted, the implementation will generate one based on
             operation_id.
-        labels (Sequence[google.cloud.servicecontrol_v1.types.LogEntry.LabelsEntry]):
+        labels (Mapping[str, str]):
             A set of user-defined (key, value) data that
             provides additional information about the log
             entry.
@@ -90,25 +93,64 @@ class LogEntry(proto.Message):
             associated with the log entry, if any.
     """
 
-    name = proto.Field(proto.STRING, number=10,)
-    timestamp = proto.Field(proto.MESSAGE, number=11, message=timestamp_pb2.Timestamp,)
-    severity = proto.Field(proto.ENUM, number=12, enum=log_severity_pb2.LogSeverity,)
+    name = proto.Field(
+        proto.STRING,
+        number=10,
+    )
+    timestamp = proto.Field(
+        proto.MESSAGE,
+        number=11,
+        message=timestamp_pb2.Timestamp,
+    )
+    severity = proto.Field(
+        proto.ENUM,
+        number=12,
+        enum=log_severity_pb2.LogSeverity,
+    )
     http_request = proto.Field(
-        proto.MESSAGE, number=14, message=gas_http_request.HttpRequest,
+        proto.MESSAGE,
+        number=14,
+        message=gas_http_request.HttpRequest,
+    )
+    trace = proto.Field(
+        proto.STRING,
+        number=15,
+    )
+    insert_id = proto.Field(
+        proto.STRING,
+        number=4,
+    )
+    labels = proto.MapField(
+        proto.STRING,
+        proto.STRING,
+        number=13,
     )
-    trace = proto.Field(proto.STRING, number=15,)
-    insert_id = proto.Field(proto.STRING, number=4,)
-    labels = proto.MapField(proto.STRING, proto.STRING, number=13,)
     proto_payload = proto.Field(
-        proto.MESSAGE, number=2, oneof="payload", message=any_pb2.Any,
+        proto.MESSAGE,
+        number=2,
+        oneof="payload",
+        message=any_pb2.Any,
+    )
+    text_payload = proto.Field(
+        proto.STRING,
+        number=3,
+        oneof="payload",
     )
-    text_payload = proto.Field(proto.STRING, number=3, oneof="payload",)
     struct_payload = proto.Field(
-        proto.MESSAGE, number=6, oneof="payload", message=struct_pb2.Struct,
+        proto.MESSAGE,
+        number=6,
+        oneof="payload",
+        message=struct_pb2.Struct,
+    )
+    operation = proto.Field(
+        proto.MESSAGE,
+        number=16,
+        message="LogEntryOperation",
     )
-    operation = proto.Field(proto.MESSAGE, number=16, message="LogEntryOperation",)
     source_location = proto.Field(
-        proto.MESSAGE, number=17, message="LogEntrySourceLocation",
+        proto.MESSAGE,
+        number=17,
+        message="LogEntrySourceLocation",
     )
 
 
@@ -134,10 +176,22 @@ class LogEntryOperation(proto.Message):
             last log entry in the operation.
     """
 
-    id = proto.Field(proto.STRING, number=1,)
-    producer = proto.Field(proto.STRING, number=2,)
-    first = proto.Field(proto.BOOL, number=3,)
-    last = proto.Field(proto.BOOL, number=4,)
+    id = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    producer = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    first = proto.Field(
+        proto.BOOL,
+        number=3,
+    )
+    last = proto.Field(
+        proto.BOOL,
+        number=4,
+    )
 
 
 class LogEntrySourceLocation(proto.Message):
@@ -162,9 +216,18 @@ class LogEntrySourceLocation(proto.Message):
             (Go), ``function`` (Python).
     """
 
-    file = proto.Field(proto.STRING, number=1,)
-    line = proto.Field(proto.INT64, number=2,)
-    function = proto.Field(proto.STRING, number=3,)
+    file = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    line = proto.Field(
+        proto.INT64,
+        number=2,
+    )
+    function = proto.Field(
+        proto.STRING,
+        number=3,
+    )
 
 
 __all__ = tuple(sorted(__protobuf__.manifest))
