@@ -16,27 +16,29 @@
 from collections import OrderedDict
 import os
 import re
-from typing import Dict, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 
 from google.api_core import client_options as client_options_lib
 from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
 from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
+from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
-from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.oauth2 import service_account  # type: ignore
+import pkg_resources
 
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
 except AttributeError:  # pragma: NO COVER
     OptionalRetry = Union[retries.Retry, object]  # type: ignore
 
-from google.cloud.servicecontrol_v2.types import service_controller
 from google.rpc import status_pb2  # type: ignore
-from .transports.base import ServiceControllerTransport, DEFAULT_CLIENT_INFO
+
+from google.cloud.servicecontrol_v2.types import service_controller
+
+from .transports.base import DEFAULT_CLIENT_INFO, ServiceControllerTransport
 from .transports.grpc import ServiceControllerGrpcTransport
 from .transports.grpc_asyncio import ServiceControllerGrpcAsyncIOTransport
 
@@ -56,7 +58,8 @@ class ServiceControllerClientMeta(type):
     _transport_registry["grpc_asyncio"] = ServiceControllerGrpcAsyncIOTransport
 
     def get_transport_class(
-        cls, label: str = None,
+        cls,
+        label: str = None,
     ) -> Type[ServiceControllerTransport]:
         """Returns an appropriate transport class.
 
@@ -78,14 +81,14 @@ class ServiceControllerClientMeta(type):
 
 class ServiceControllerClient(metaclass=ServiceControllerClientMeta):
     """`Service Control API
-    v2 </service-infrastructure/docs/service-control>`__
+    v2 <https://cloud.google.com/service-infrastructure/docs/service-control/access-control>`__
 
     Private Preview. This feature is only available for approved
     services.
 
     This API provides admission control and telemetry reporting for
     services that are integrated with `Service
-    Infrastructure </service-infrastructure>`__.
+    Infrastructure <https://cloud.google.com/service-infrastructure>`__.
     """
 
     @staticmethod
@@ -171,7 +174,9 @@ class ServiceControllerClient(metaclass=ServiceControllerClientMeta):
         return self._transport
 
     @staticmethod
-    def common_billing_account_path(billing_account: str,) -> str:
+    def common_billing_account_path(
+        billing_account: str,
+    ) -> str:
         """Returns a fully-qualified billing_account string."""
         return "billingAccounts/{billing_account}".format(
             billing_account=billing_account,
@@ -184,9 +189,13 @@ class ServiceControllerClient(metaclass=ServiceControllerClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_folder_path(folder: str,) -> str:
+    def common_folder_path(
+        folder: str,
+    ) -> str:
         """Returns a fully-qualified folder string."""
-        return "folders/{folder}".format(folder=folder,)
+        return "folders/{folder}".format(
+            folder=folder,
+        )
 
     @staticmethod
     def parse_common_folder_path(path: str) -> Dict[str, str]:
@@ -195,9 +204,13 @@ class ServiceControllerClient(metaclass=ServiceControllerClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_organization_path(organization: str,) -> str:
+    def common_organization_path(
+        organization: str,
+    ) -> str:
         """Returns a fully-qualified organization string."""
-        return "organizations/{organization}".format(organization=organization,)
+        return "organizations/{organization}".format(
+            organization=organization,
+        )
 
     @staticmethod
     def parse_common_organization_path(path: str) -> Dict[str, str]:
@@ -206,9 +219,13 @@ class ServiceControllerClient(metaclass=ServiceControllerClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_project_path(project: str,) -> str:
+    def common_project_path(
+        project: str,
+    ) -> str:
         """Returns a fully-qualified project string."""
-        return "projects/{project}".format(project=project,)
+        return "projects/{project}".format(
+            project=project,
+        )
 
     @staticmethod
     def parse_common_project_path(path: str) -> Dict[str, str]:
@@ -217,10 +234,14 @@ class ServiceControllerClient(metaclass=ServiceControllerClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_location_path(project: str, location: str,) -> str:
+    def common_location_path(
+        project: str,
+        location: str,
+    ) -> str:
         """Returns a fully-qualified location string."""
         return "projects/{project}/locations/{location}".format(
-            project=project, location=location,
+            project=project,
+            location=location,
         )
 
     @staticmethod
@@ -407,11 +428,12 @@ class ServiceControllerClient(metaclass=ServiceControllerClientMeta):
 
         This method provides admission control for services that are
         integrated with `Service
-        Infrastructure </service-infrastructure>`__. It checks whether
-        an operation should be allowed based on the service
-        configuration and relevant policies. It must be called before
-        the operation is executed. For more information, see `Admission
-        Control </service-infrastructure/docs/admission-control>`__.
+        Infrastructure <https://cloud.google.com/service-infrastructure>`__.
+        It checks whether an operation should be allowed based on the
+        service configuration and relevant policies. It must be called
+        before the operation is executed. For more information, see
+        `Admission
+        Control <https://cloud.google.com/service-infrastructure/docs/admission-control>`__.
 
         NOTE: The admission control has an expected policy propagation
         delay of 60s. The caller **must** not depend on the most recent
@@ -426,7 +448,6 @@ class ServiceControllerClient(metaclass=ServiceControllerClientMeta):
         `Service Control API Access
         Control <https://cloud.google.com/service-infrastructure/docs/service-control/access-control>`__.
 
-
         .. code-block:: python
 
             from google.cloud import servicecontrol_v2
@@ -473,8 +494,21 @@ class ServiceControllerClient(metaclass=ServiceControllerClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.check]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (("service_name", request.service_name),)
+            ),
+        )
+
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -492,11 +526,11 @@ class ServiceControllerClient(metaclass=ServiceControllerClientMeta):
 
         This method provides telemetry reporting for services that are
         integrated with `Service
-        Infrastructure </service-infrastructure>`__. It reports a list
-        of operations that have occurred on a service. It must be called
-        after the operations have been executed. For more information,
-        see `Telemetry
-        Reporting </service-infrastructure/docs/telemetry-reporting>`__.
+        Infrastructure <https://cloud.google.com/service-infrastructure>`__.
+        It reports a list of operations that have occurred on a service.
+        It must be called after the operations have been executed. For
+        more information, see `Telemetry
+        Reporting <https://cloud.google.com/service-infrastructure/docs/telemetry-reporting>`__.
 
         NOTE: The telemetry reporting has a hard limit of 1000
         operations and 1MB per Report call. It is recommended to have no
@@ -507,7 +541,6 @@ class ServiceControllerClient(metaclass=ServiceControllerClientMeta):
         `Service Control API Access
         Control <https://cloud.google.com/service-infrastructure/docs/service-control/access-control>`__.
 
-
         .. code-block:: python
 
             from google.cloud import servicecontrol_v2
@@ -556,8 +589,21 @@ class ServiceControllerClient(metaclass=ServiceControllerClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.report]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (("service_name", request.service_name),)
+            ),
+        )
+
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
