@@ -13,39 +13,32 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-import os
-import mock
-
-import grpc
-from grpc.experimental import aio
 import math
-import pytest
-from proto.marshal.rules.dates import DurationRule, TimestampRule
-
+import os
 
 from google.api import distribution_pb2  # type: ignore
+from google.api_core import gapic_v1, grpc_helpers, grpc_helpers_async, path_template
 from google.api_core import client_options
 from google.api_core import exceptions as core_exceptions
-from google.api_core import gapic_v1
-from google.api_core import grpc_helpers
-from google.api_core import grpc_helpers_async
-from google.api_core import path_template
+import google.auth
 from google.auth import credentials as ga_credentials
 from google.auth.exceptions import MutualTLSChannelError
-from google.cloud.servicecontrol_v1.services.quota_controller import (
-    QuotaControllerAsyncClient,
-)
-from google.cloud.servicecontrol_v1.services.quota_controller import (
-    QuotaControllerClient,
-)
-from google.cloud.servicecontrol_v1.services.quota_controller import transports
-from google.cloud.servicecontrol_v1.types import distribution as gas_distribution
-from google.cloud.servicecontrol_v1.types import metric_value
-from google.cloud.servicecontrol_v1.types import quota_controller
 from google.oauth2 import service_account
 from google.protobuf import any_pb2  # type: ignore
 from google.protobuf import timestamp_pb2  # type: ignore
-import google.auth
+import grpc
+from grpc.experimental import aio
+import mock
+from proto.marshal.rules.dates import DurationRule, TimestampRule
+import pytest
+
+from google.cloud.servicecontrol_v1.services.quota_controller import (
+    QuotaControllerAsyncClient,
+    QuotaControllerClient,
+    transports,
+)
+from google.cloud.servicecontrol_v1.types import distribution as gas_distribution
+from google.cloud.servicecontrol_v1.types import metric_value, quota_controller
 
 
 def client_cert_source_callback():
@@ -93,20 +86,26 @@ def test__get_default_mtls_endpoint():
 
 
 @pytest.mark.parametrize(
-    "client_class", [QuotaControllerClient, QuotaControllerAsyncClient,]
+    "client_class,transport_name",
+    [
+        (QuotaControllerClient, "grpc"),
+        (QuotaControllerAsyncClient, "grpc_asyncio"),
+    ],
 )
-def test_quota_controller_client_from_service_account_info(client_class):
+def test_quota_controller_client_from_service_account_info(
+    client_class, transport_name
+):
     creds = ga_credentials.AnonymousCredentials()
     with mock.patch.object(
         service_account.Credentials, "from_service_account_info"
     ) as factory:
         factory.return_value = creds
         info = {"valid": True}
-        client = client_class.from_service_account_info(info)
+        client = client_class.from_service_account_info(info, transport=transport_name)
         assert client.transport._credentials == creds
         assert isinstance(client, client_class)
 
-        assert client.transport._host == "servicecontrol.googleapis.com:443"
+        assert client.transport._host == ("servicecontrol.googleapis.com:443")
 
 
 @pytest.mark.parametrize(
@@ -135,23 +134,33 @@ def test_quota_controller_client_service_account_always_use_jwt(
 
 
 @pytest.mark.parametrize(
-    "client_class", [QuotaControllerClient, QuotaControllerAsyncClient,]
+    "client_class,transport_name",
+    [
+        (QuotaControllerClient, "grpc"),
+        (QuotaControllerAsyncClient, "grpc_asyncio"),
+    ],
 )
-def test_quota_controller_client_from_service_account_file(client_class):
+def test_quota_controller_client_from_service_account_file(
+    client_class, transport_name
+):
     creds = ga_credentials.AnonymousCredentials()
     with mock.patch.object(
         service_account.Credentials, "from_service_account_file"
     ) as factory:
         factory.return_value = creds
-        client = client_class.from_service_account_file("dummy/file/path.json")
+        client = client_class.from_service_account_file(
+            "dummy/file/path.json", transport=transport_name
+        )
         assert client.transport._credentials == creds
         assert isinstance(client, client_class)
 
-        client = client_class.from_service_account_json("dummy/file/path.json")
+        client = client_class.from_service_account_json(
+            "dummy/file/path.json", transport=transport_name
+        )
         assert client.transport._credentials == creds
         assert isinstance(client, client_class)
 
-        assert client.transport._host == "servicecontrol.googleapis.com:443"
+        assert client.transport._host == ("servicecontrol.googleapis.com:443")
 
 
 def test_quota_controller_client_get_transport_class():
@@ -509,7 +518,9 @@ def test_quota_controller_client_client_options_scopes(
     client_class, transport_class, transport_name
 ):
     # Check the case scopes are provided.
-    options = client_options.ClientOptions(scopes=["1", "2"],)
+    options = client_options.ClientOptions(
+        scopes=["1", "2"],
+    )
     with mock.patch.object(transport_class, "__init__") as patched:
         patched.return_value = None
         client = client_class(client_options=options, transport=transport_name)
@@ -652,10 +663,17 @@ def test_quota_controller_client_create_channel_credentials_file(
         )
 
 
-@pytest.mark.parametrize("request_type", [quota_controller.AllocateQuotaRequest, dict,])
+@pytest.mark.parametrize(
+    "request_type",
+    [
+        quota_controller.AllocateQuotaRequest,
+        dict,
+    ],
+)
 def test_allocate_quota(request_type, transport: str = "grpc"):
     client = QuotaControllerClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -686,7 +704,8 @@ def test_allocate_quota_empty_call():
     # This test is a coverage failsafe to make sure that totally empty calls,
     # i.e. request == None and no flattened fields passed, work.
     client = QuotaControllerClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport="grpc",
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="grpc",
     )
 
     # Mock the actual call within the gRPC stub, and fake the request.
@@ -702,7 +721,8 @@ async def test_allocate_quota_async(
     transport: str = "grpc_asyncio", request_type=quota_controller.AllocateQuotaRequest
 ):
     client = QuotaControllerAsyncClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -736,6 +756,67 @@ async def test_allocate_quota_async_from_dict():
     await test_allocate_quota_async(request_type=dict)
 
 
+def test_allocate_quota_field_headers():
+    client = QuotaControllerClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
+
+    # Any value that is part of the HTTP/1.1 URI should be sent as
+    # a field header. Set these to a non-empty value.
+    request = quota_controller.AllocateQuotaRequest()
+
+    request.service_name = "service_name_value"
+
+    # Mock the actual call within the gRPC stub, and fake the request.
+    with mock.patch.object(type(client.transport.allocate_quota), "__call__") as call:
+        call.return_value = quota_controller.AllocateQuotaResponse()
+        client.allocate_quota(request)
+
+        # Establish that the underlying gRPC stub method was called.
+        assert len(call.mock_calls) == 1
+        _, args, _ = call.mock_calls[0]
+        assert args[0] == request
+
+    # Establish that the field header was sent.
+    _, _, kw = call.mock_calls[0]
+    assert (
+        "x-goog-request-params",
+        "service_name=service_name_value",
+    ) in kw["metadata"]
+
+
+@pytest.mark.asyncio
+async def test_allocate_quota_field_headers_async():
+    client = QuotaControllerAsyncClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
+
+    # Any value that is part of the HTTP/1.1 URI should be sent as
+    # a field header. Set these to a non-empty value.
+    request = quota_controller.AllocateQuotaRequest()
+
+    request.service_name = "service_name_value"
+
+    # Mock the actual call within the gRPC stub, and fake the request.
+    with mock.patch.object(type(client.transport.allocate_quota), "__call__") as call:
+        call.return_value = grpc_helpers_async.FakeUnaryUnaryCall(
+            quota_controller.AllocateQuotaResponse()
+        )
+        await client.allocate_quota(request)
+
+        # Establish that the underlying gRPC stub method was called.
+        assert len(call.mock_calls)
+        _, args, _ = call.mock_calls[0]
+        assert args[0] == request
+
+    # Establish that the field header was sent.
+    _, _, kw = call.mock_calls[0]
+    assert (
+        "x-goog-request-params",
+        "service_name=service_name_value",
+    ) in kw["metadata"]
+
+
 def test_credentials_transport_error():
     # It is an error to provide credentials and a transport instance.
     transport = transports.QuotaControllerGrpcTransport(
@@ -743,7 +824,8 @@ def test_credentials_transport_error():
     )
     with pytest.raises(ValueError):
         client = QuotaControllerClient(
-            credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+            credentials=ga_credentials.AnonymousCredentials(),
+            transport=transport,
         )
 
     # It is an error to provide a credentials file and a transport instance.
@@ -763,7 +845,10 @@ def test_credentials_transport_error():
     options = client_options.ClientOptions()
     options.api_key = "api_key"
     with pytest.raises(ValueError):
-        client = QuotaControllerClient(client_options=options, transport=transport,)
+        client = QuotaControllerClient(
+            client_options=options,
+            transport=transport,
+        )
 
     # It is an error to provide an api_key and a credential.
     options = mock.Mock()
@@ -779,7 +864,8 @@ def test_credentials_transport_error():
     )
     with pytest.raises(ValueError):
         client = QuotaControllerClient(
-            client_options={"scopes": ["1", "2"]}, transport=transport,
+            client_options={"scopes": ["1", "2"]},
+            transport=transport,
         )
 
 
@@ -822,10 +908,28 @@ def test_transport_adc(transport_class):
         adc.assert_called_once()
 
 
+@pytest.mark.parametrize(
+    "transport_name",
+    [
+        "grpc",
+    ],
+)
+def test_transport_kind(transport_name):
+    transport = QuotaControllerClient.get_transport_class(transport_name)(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
+    assert transport.kind == transport_name
+
+
 def test_transport_grpc_default():
     # A client should use the gRPC transport by default.
-    client = QuotaControllerClient(credentials=ga_credentials.AnonymousCredentials(),)
-    assert isinstance(client.transport, transports.QuotaControllerGrpcTransport,)
+    client = QuotaControllerClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
+    assert isinstance(
+        client.transport,
+        transports.QuotaControllerGrpcTransport,
+    )
 
 
 def test_quota_controller_base_transport_error():
@@ -857,6 +961,14 @@ def test_quota_controller_base_transport():
     with pytest.raises(NotImplementedError):
         transport.close()
 
+    # Catch all for all remaining methods and properties
+    remainder = [
+        "kind",
+    ]
+    for r in remainder:
+        with pytest.raises(NotImplementedError):
+            getattr(transport, r)()
+
 
 def test_quota_controller_base_transport_with_credentials_file():
     # Instantiate the base transport with a credentials file
@@ -868,7 +980,8 @@ def test_quota_controller_base_transport_with_credentials_file():
         Transport.return_value = None
         load_creds.return_value = (ga_credentials.AnonymousCredentials(), None)
         transport = transports.QuotaControllerTransport(
-            credentials_file="credentials.json", quota_project_id="octopus",
+            credentials_file="credentials.json",
+            quota_project_id="octopus",
         )
         load_creds.assert_called_once_with(
             "credentials.json",
@@ -1013,24 +1126,40 @@ def test_quota_controller_grpc_transport_client_cert_source_for_mtls(transport_c
             )
 
 
-def test_quota_controller_host_no_port():
+@pytest.mark.parametrize(
+    "transport_name",
+    [
+        "grpc",
+        "grpc_asyncio",
+    ],
+)
+def test_quota_controller_host_no_port(transport_name):
     client = QuotaControllerClient(
         credentials=ga_credentials.AnonymousCredentials(),
         client_options=client_options.ClientOptions(
             api_endpoint="servicecontrol.googleapis.com"
         ),
+        transport=transport_name,
     )
-    assert client.transport._host == "servicecontrol.googleapis.com:443"
+    assert client.transport._host == ("servicecontrol.googleapis.com:443")
 
 
-def test_quota_controller_host_with_port():
+@pytest.mark.parametrize(
+    "transport_name",
+    [
+        "grpc",
+        "grpc_asyncio",
+    ],
+)
+def test_quota_controller_host_with_port(transport_name):
     client = QuotaControllerClient(
         credentials=ga_credentials.AnonymousCredentials(),
         client_options=client_options.ClientOptions(
             api_endpoint="servicecontrol.googleapis.com:8000"
         ),
+        transport=transport_name,
     )
-    assert client.transport._host == "servicecontrol.googleapis.com:8000"
+    assert client.transport._host == ("servicecontrol.googleapis.com:8000")
 
 
 def test_quota_controller_grpc_transport_channel():
@@ -1038,7 +1167,8 @@ def test_quota_controller_grpc_transport_channel():
 
     # Check that channel is used if provided.
     transport = transports.QuotaControllerGrpcTransport(
-        host="squid.clam.whelk", channel=channel,
+        host="squid.clam.whelk",
+        channel=channel,
     )
     assert transport.grpc_channel == channel
     assert transport._host == "squid.clam.whelk:443"
@@ -1050,7 +1180,8 @@ def test_quota_controller_grpc_asyncio_transport_channel():
 
     # Check that channel is used if provided.
     transport = transports.QuotaControllerGrpcAsyncIOTransport(
-        host="squid.clam.whelk", channel=channel,
+        host="squid.clam.whelk",
+        channel=channel,
     )
     assert transport.grpc_channel == channel
     assert transport._host == "squid.clam.whelk:443"
@@ -1179,7 +1310,9 @@ def test_parse_common_billing_account_path():
 
 def test_common_folder_path():
     folder = "whelk"
-    expected = "folders/{folder}".format(folder=folder,)
+    expected = "folders/{folder}".format(
+        folder=folder,
+    )
     actual = QuotaControllerClient.common_folder_path(folder)
     assert expected == actual
 
@@ -1197,7 +1330,9 @@ def test_parse_common_folder_path():
 
 def test_common_organization_path():
     organization = "oyster"
-    expected = "organizations/{organization}".format(organization=organization,)
+    expected = "organizations/{organization}".format(
+        organization=organization,
+    )
     actual = QuotaControllerClient.common_organization_path(organization)
     assert expected == actual
 
@@ -1215,7 +1350,9 @@ def test_parse_common_organization_path():
 
 def test_common_project_path():
     project = "cuttlefish"
-    expected = "projects/{project}".format(project=project,)
+    expected = "projects/{project}".format(
+        project=project,
+    )
     actual = QuotaControllerClient.common_project_path(project)
     assert expected == actual
 
@@ -1235,7 +1372,8 @@ def test_common_location_path():
     project = "winkle"
     location = "nautilus"
     expected = "projects/{project}/locations/{location}".format(
-        project=project, location=location,
+        project=project,
+        location=location,
     )
     actual = QuotaControllerClient.common_location_path(project, location)
     assert expected == actual
@@ -1260,7 +1398,8 @@ def test_client_with_default_client_info():
         transports.QuotaControllerTransport, "_prep_wrapped_messages"
     ) as prep:
         client = QuotaControllerClient(
-            credentials=ga_credentials.AnonymousCredentials(), client_info=client_info,
+            credentials=ga_credentials.AnonymousCredentials(),
+            client_info=client_info,
         )
         prep.assert_called_once_with(client_info)
 
@@ -1269,7 +1408,8 @@ def test_client_with_default_client_info():
     ) as prep:
         transport_class = QuotaControllerClient.get_transport_class()
         transport = transport_class(
-            credentials=ga_credentials.AnonymousCredentials(), client_info=client_info,
+            credentials=ga_credentials.AnonymousCredentials(),
+            client_info=client_info,
         )
         prep.assert_called_once_with(client_info)
 
@@ -1277,7 +1417,8 @@ def test_client_with_default_client_info():
 @pytest.mark.asyncio
 async def test_transport_close_async():
     client = QuotaControllerAsyncClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport="grpc_asyncio",
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="grpc_asyncio",
     )
     with mock.patch.object(
         type(getattr(client.transport, "grpc_channel")), "close"
