@@ -13,46 +13,42 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-import os
-import mock
-
-import grpc
-from grpc.experimental import aio
 import math
-import pytest
-from proto.marshal.rules.dates import DurationRule, TimestampRule
-
+import os
 
 from google.api import distribution_pb2  # type: ignore
+from google.api_core import gapic_v1, grpc_helpers, grpc_helpers_async, path_template
 from google.api_core import client_options
 from google.api_core import exceptions as core_exceptions
-from google.api_core import gapic_v1
-from google.api_core import grpc_helpers
-from google.api_core import grpc_helpers_async
-from google.api_core import path_template
+import google.auth
 from google.auth import credentials as ga_credentials
 from google.auth.exceptions import MutualTLSChannelError
-from google.cloud.servicecontrol_v1.services.service_controller import (
-    ServiceControllerAsyncClient,
-)
-from google.cloud.servicecontrol_v1.services.service_controller import (
-    ServiceControllerClient,
-)
-from google.cloud.servicecontrol_v1.services.service_controller import transports
-from google.cloud.servicecontrol_v1.types import check_error
-from google.cloud.servicecontrol_v1.types import distribution as gas_distribution
-from google.cloud.servicecontrol_v1.types import http_request
-from google.cloud.servicecontrol_v1.types import log_entry
-from google.cloud.servicecontrol_v1.types import metric_value
-from google.cloud.servicecontrol_v1.types import operation
-from google.cloud.servicecontrol_v1.types import service_controller
 from google.logging.type import log_severity_pb2  # type: ignore
 from google.oauth2 import service_account
 from google.protobuf import any_pb2  # type: ignore
 from google.protobuf import duration_pb2  # type: ignore
 from google.protobuf import struct_pb2  # type: ignore
 from google.protobuf import timestamp_pb2  # type: ignore
-import google.auth
+import grpc
+from grpc.experimental import aio
+import mock
+from proto.marshal.rules.dates import DurationRule, TimestampRule
+import pytest
+
+from google.cloud.servicecontrol_v1.services.service_controller import (
+    ServiceControllerAsyncClient,
+    ServiceControllerClient,
+    transports,
+)
+from google.cloud.servicecontrol_v1.types import (
+    http_request,
+    log_entry,
+    metric_value,
+    operation,
+    service_controller,
+)
+from google.cloud.servicecontrol_v1.types import distribution as gas_distribution
+from google.cloud.servicecontrol_v1.types import check_error
 
 
 def client_cert_source_callback():
@@ -101,20 +97,26 @@ def test__get_default_mtls_endpoint():
 
 
 @pytest.mark.parametrize(
-    "client_class", [ServiceControllerClient, ServiceControllerAsyncClient,]
+    "client_class,transport_name",
+    [
+        (ServiceControllerClient, "grpc"),
+        (ServiceControllerAsyncClient, "grpc_asyncio"),
+    ],
 )
-def test_service_controller_client_from_service_account_info(client_class):
+def test_service_controller_client_from_service_account_info(
+    client_class, transport_name
+):
     creds = ga_credentials.AnonymousCredentials()
     with mock.patch.object(
         service_account.Credentials, "from_service_account_info"
     ) as factory:
         factory.return_value = creds
         info = {"valid": True}
-        client = client_class.from_service_account_info(info)
+        client = client_class.from_service_account_info(info, transport=transport_name)
         assert client.transport._credentials == creds
         assert isinstance(client, client_class)
 
-        assert client.transport._host == "servicecontrol.googleapis.com:443"
+        assert client.transport._host == ("servicecontrol.googleapis.com:443")
 
 
 @pytest.mark.parametrize(
@@ -143,23 +145,33 @@ def test_service_controller_client_service_account_always_use_jwt(
 
 
 @pytest.mark.parametrize(
-    "client_class", [ServiceControllerClient, ServiceControllerAsyncClient,]
+    "client_class,transport_name",
+    [
+        (ServiceControllerClient, "grpc"),
+        (ServiceControllerAsyncClient, "grpc_asyncio"),
+    ],
 )
-def test_service_controller_client_from_service_account_file(client_class):
+def test_service_controller_client_from_service_account_file(
+    client_class, transport_name
+):
     creds = ga_credentials.AnonymousCredentials()
     with mock.patch.object(
         service_account.Credentials, "from_service_account_file"
     ) as factory:
         factory.return_value = creds
-        client = client_class.from_service_account_file("dummy/file/path.json")
+        client = client_class.from_service_account_file(
+            "dummy/file/path.json", transport=transport_name
+        )
         assert client.transport._credentials == creds
         assert isinstance(client, client_class)
 
-        client = client_class.from_service_account_json("dummy/file/path.json")
+        client = client_class.from_service_account_json(
+            "dummy/file/path.json", transport=transport_name
+        )
         assert client.transport._credentials == creds
         assert isinstance(client, client_class)
 
-        assert client.transport._host == "servicecontrol.googleapis.com:443"
+        assert client.transport._host == ("servicecontrol.googleapis.com:443")
 
 
 def test_service_controller_client_get_transport_class():
@@ -517,7 +529,9 @@ def test_service_controller_client_client_options_scopes(
     client_class, transport_class, transport_name
 ):
     # Check the case scopes are provided.
-    options = client_options.ClientOptions(scopes=["1", "2"],)
+    options = client_options.ClientOptions(
+        scopes=["1", "2"],
+    )
     with mock.patch.object(transport_class, "__init__") as patched:
         patched.return_value = None
         client = client_class(client_options=options, transport=transport_name)
@@ -660,10 +674,17 @@ def test_service_controller_client_create_channel_credentials_file(
         )
 
 
-@pytest.mark.parametrize("request_type", [service_controller.CheckRequest, dict,])
+@pytest.mark.parametrize(
+    "request_type",
+    [
+        service_controller.CheckRequest,
+        dict,
+    ],
+)
 def test_check(request_type, transport: str = "grpc"):
     client = ServiceControllerClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -696,7 +717,8 @@ def test_check_empty_call():
     # This test is a coverage failsafe to make sure that totally empty calls,
     # i.e. request == None and no flattened fields passed, work.
     client = ServiceControllerClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport="grpc",
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="grpc",
     )
 
     # Mock the actual call within the gRPC stub, and fake the request.
@@ -712,7 +734,8 @@ async def test_check_async(
     transport: str = "grpc_asyncio", request_type=service_controller.CheckRequest
 ):
     client = ServiceControllerAsyncClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -748,10 +771,78 @@ async def test_check_async_from_dict():
     await test_check_async(request_type=dict)
 
 
-@pytest.mark.parametrize("request_type", [service_controller.ReportRequest, dict,])
+def test_check_field_headers():
+    client = ServiceControllerClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
+
+    # Any value that is part of the HTTP/1.1 URI should be sent as
+    # a field header. Set these to a non-empty value.
+    request = service_controller.CheckRequest()
+
+    request.service_name = "service_name_value"
+
+    # Mock the actual call within the gRPC stub, and fake the request.
+    with mock.patch.object(type(client.transport.check), "__call__") as call:
+        call.return_value = service_controller.CheckResponse()
+        client.check(request)
+
+        # Establish that the underlying gRPC stub method was called.
+        assert len(call.mock_calls) == 1
+        _, args, _ = call.mock_calls[0]
+        assert args[0] == request
+
+    # Establish that the field header was sent.
+    _, _, kw = call.mock_calls[0]
+    assert (
+        "x-goog-request-params",
+        "service_name=service_name_value",
+    ) in kw["metadata"]
+
+
+@pytest.mark.asyncio
+async def test_check_field_headers_async():
+    client = ServiceControllerAsyncClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
+
+    # Any value that is part of the HTTP/1.1 URI should be sent as
+    # a field header. Set these to a non-empty value.
+    request = service_controller.CheckRequest()
+
+    request.service_name = "service_name_value"
+
+    # Mock the actual call within the gRPC stub, and fake the request.
+    with mock.patch.object(type(client.transport.check), "__call__") as call:
+        call.return_value = grpc_helpers_async.FakeUnaryUnaryCall(
+            service_controller.CheckResponse()
+        )
+        await client.check(request)
+
+        # Establish that the underlying gRPC stub method was called.
+        assert len(call.mock_calls)
+        _, args, _ = call.mock_calls[0]
+        assert args[0] == request
+
+    # Establish that the field header was sent.
+    _, _, kw = call.mock_calls[0]
+    assert (
+        "x-goog-request-params",
+        "service_name=service_name_value",
+    ) in kw["metadata"]
+
+
+@pytest.mark.parametrize(
+    "request_type",
+    [
+        service_controller.ReportRequest,
+        dict,
+    ],
+)
 def test_report(request_type, transport: str = "grpc"):
     client = ServiceControllerClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -782,7 +873,8 @@ def test_report_empty_call():
     # This test is a coverage failsafe to make sure that totally empty calls,
     # i.e. request == None and no flattened fields passed, work.
     client = ServiceControllerClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport="grpc",
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="grpc",
     )
 
     # Mock the actual call within the gRPC stub, and fake the request.
@@ -798,7 +890,8 @@ async def test_report_async(
     transport: str = "grpc_asyncio", request_type=service_controller.ReportRequest
 ):
     client = ServiceControllerAsyncClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -832,6 +925,67 @@ async def test_report_async_from_dict():
     await test_report_async(request_type=dict)
 
 
+def test_report_field_headers():
+    client = ServiceControllerClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
+
+    # Any value that is part of the HTTP/1.1 URI should be sent as
+    # a field header. Set these to a non-empty value.
+    request = service_controller.ReportRequest()
+
+    request.service_name = "service_name_value"
+
+    # Mock the actual call within the gRPC stub, and fake the request.
+    with mock.patch.object(type(client.transport.report), "__call__") as call:
+        call.return_value = service_controller.ReportResponse()
+        client.report(request)
+
+        # Establish that the underlying gRPC stub method was called.
+        assert len(call.mock_calls) == 1
+        _, args, _ = call.mock_calls[0]
+        assert args[0] == request
+
+    # Establish that the field header was sent.
+    _, _, kw = call.mock_calls[0]
+    assert (
+        "x-goog-request-params",
+        "service_name=service_name_value",
+    ) in kw["metadata"]
+
+
+@pytest.mark.asyncio
+async def test_report_field_headers_async():
+    client = ServiceControllerAsyncClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
+
+    # Any value that is part of the HTTP/1.1 URI should be sent as
+    # a field header. Set these to a non-empty value.
+    request = service_controller.ReportRequest()
+
+    request.service_name = "service_name_value"
+
+    # Mock the actual call within the gRPC stub, and fake the request.
+    with mock.patch.object(type(client.transport.report), "__call__") as call:
+        call.return_value = grpc_helpers_async.FakeUnaryUnaryCall(
+            service_controller.ReportResponse()
+        )
+        await client.report(request)
+
+        # Establish that the underlying gRPC stub method was called.
+        assert len(call.mock_calls)
+        _, args, _ = call.mock_calls[0]
+        assert args[0] == request
+
+    # Establish that the field header was sent.
+    _, _, kw = call.mock_calls[0]
+    assert (
+        "x-goog-request-params",
+        "service_name=service_name_value",
+    ) in kw["metadata"]
+
+
 def test_credentials_transport_error():
     # It is an error to provide credentials and a transport instance.
     transport = transports.ServiceControllerGrpcTransport(
@@ -839,7 +993,8 @@ def test_credentials_transport_error():
     )
     with pytest.raises(ValueError):
         client = ServiceControllerClient(
-            credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+            credentials=ga_credentials.AnonymousCredentials(),
+            transport=transport,
         )
 
     # It is an error to provide a credentials file and a transport instance.
@@ -859,7 +1014,10 @@ def test_credentials_transport_error():
     options = client_options.ClientOptions()
     options.api_key = "api_key"
     with pytest.raises(ValueError):
-        client = ServiceControllerClient(client_options=options, transport=transport,)
+        client = ServiceControllerClient(
+            client_options=options,
+            transport=transport,
+        )
 
     # It is an error to provide an api_key and a credential.
     options = mock.Mock()
@@ -875,7 +1033,8 @@ def test_credentials_transport_error():
     )
     with pytest.raises(ValueError):
         client = ServiceControllerClient(
-            client_options={"scopes": ["1", "2"]}, transport=transport,
+            client_options={"scopes": ["1", "2"]},
+            transport=transport,
         )
 
 
@@ -918,10 +1077,28 @@ def test_transport_adc(transport_class):
         adc.assert_called_once()
 
 
+@pytest.mark.parametrize(
+    "transport_name",
+    [
+        "grpc",
+    ],
+)
+def test_transport_kind(transport_name):
+    transport = ServiceControllerClient.get_transport_class(transport_name)(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
+    assert transport.kind == transport_name
+
+
 def test_transport_grpc_default():
     # A client should use the gRPC transport by default.
-    client = ServiceControllerClient(credentials=ga_credentials.AnonymousCredentials(),)
-    assert isinstance(client.transport, transports.ServiceControllerGrpcTransport,)
+    client = ServiceControllerClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
+    assert isinstance(
+        client.transport,
+        transports.ServiceControllerGrpcTransport,
+    )
 
 
 def test_service_controller_base_transport_error():
@@ -956,6 +1133,14 @@ def test_service_controller_base_transport():
     with pytest.raises(NotImplementedError):
         transport.close()
 
+    # Catch all for all remaining methods and properties
+    remainder = [
+        "kind",
+    ]
+    for r in remainder:
+        with pytest.raises(NotImplementedError):
+            getattr(transport, r)()
+
 
 def test_service_controller_base_transport_with_credentials_file():
     # Instantiate the base transport with a credentials file
@@ -967,7 +1152,8 @@ def test_service_controller_base_transport_with_credentials_file():
         Transport.return_value = None
         load_creds.return_value = (ga_credentials.AnonymousCredentials(), None)
         transport = transports.ServiceControllerTransport(
-            credentials_file="credentials.json", quota_project_id="octopus",
+            credentials_file="credentials.json",
+            quota_project_id="octopus",
         )
         load_creds.assert_called_once_with(
             "credentials.json",
@@ -1112,24 +1298,40 @@ def test_service_controller_grpc_transport_client_cert_source_for_mtls(transport
             )
 
 
-def test_service_controller_host_no_port():
+@pytest.mark.parametrize(
+    "transport_name",
+    [
+        "grpc",
+        "grpc_asyncio",
+    ],
+)
+def test_service_controller_host_no_port(transport_name):
     client = ServiceControllerClient(
         credentials=ga_credentials.AnonymousCredentials(),
         client_options=client_options.ClientOptions(
             api_endpoint="servicecontrol.googleapis.com"
         ),
+        transport=transport_name,
     )
-    assert client.transport._host == "servicecontrol.googleapis.com:443"
+    assert client.transport._host == ("servicecontrol.googleapis.com:443")
 
 
-def test_service_controller_host_with_port():
+@pytest.mark.parametrize(
+    "transport_name",
+    [
+        "grpc",
+        "grpc_asyncio",
+    ],
+)
+def test_service_controller_host_with_port(transport_name):
     client = ServiceControllerClient(
         credentials=ga_credentials.AnonymousCredentials(),
         client_options=client_options.ClientOptions(
             api_endpoint="servicecontrol.googleapis.com:8000"
         ),
+        transport=transport_name,
     )
-    assert client.transport._host == "servicecontrol.googleapis.com:8000"
+    assert client.transport._host == ("servicecontrol.googleapis.com:8000")
 
 
 def test_service_controller_grpc_transport_channel():
@@ -1137,7 +1339,8 @@ def test_service_controller_grpc_transport_channel():
 
     # Check that channel is used if provided.
     transport = transports.ServiceControllerGrpcTransport(
-        host="squid.clam.whelk", channel=channel,
+        host="squid.clam.whelk",
+        channel=channel,
     )
     assert transport.grpc_channel == channel
     assert transport._host == "squid.clam.whelk:443"
@@ -1149,7 +1352,8 @@ def test_service_controller_grpc_asyncio_transport_channel():
 
     # Check that channel is used if provided.
     transport = transports.ServiceControllerGrpcAsyncIOTransport(
-        host="squid.clam.whelk", channel=channel,
+        host="squid.clam.whelk",
+        channel=channel,
     )
     assert transport.grpc_channel == channel
     assert transport._host == "squid.clam.whelk:443"
@@ -1278,7 +1482,9 @@ def test_parse_common_billing_account_path():
 
 def test_common_folder_path():
     folder = "whelk"
-    expected = "folders/{folder}".format(folder=folder,)
+    expected = "folders/{folder}".format(
+        folder=folder,
+    )
     actual = ServiceControllerClient.common_folder_path(folder)
     assert expected == actual
 
@@ -1296,7 +1502,9 @@ def test_parse_common_folder_path():
 
 def test_common_organization_path():
     organization = "oyster"
-    expected = "organizations/{organization}".format(organization=organization,)
+    expected = "organizations/{organization}".format(
+        organization=organization,
+    )
     actual = ServiceControllerClient.common_organization_path(organization)
     assert expected == actual
 
@@ -1314,7 +1522,9 @@ def test_parse_common_organization_path():
 
 def test_common_project_path():
     project = "cuttlefish"
-    expected = "projects/{project}".format(project=project,)
+    expected = "projects/{project}".format(
+        project=project,
+    )
     actual = ServiceControllerClient.common_project_path(project)
     assert expected == actual
 
@@ -1334,7 +1544,8 @@ def test_common_location_path():
     project = "winkle"
     location = "nautilus"
     expected = "projects/{project}/locations/{location}".format(
-        project=project, location=location,
+        project=project,
+        location=location,
     )
     actual = ServiceControllerClient.common_location_path(project, location)
     assert expected == actual
@@ -1359,7 +1570,8 @@ def test_client_with_default_client_info():
         transports.ServiceControllerTransport, "_prep_wrapped_messages"
     ) as prep:
         client = ServiceControllerClient(
-            credentials=ga_credentials.AnonymousCredentials(), client_info=client_info,
+            credentials=ga_credentials.AnonymousCredentials(),
+            client_info=client_info,
         )
         prep.assert_called_once_with(client_info)
 
@@ -1368,7 +1580,8 @@ def test_client_with_default_client_info():
     ) as prep:
         transport_class = ServiceControllerClient.get_transport_class()
         transport = transport_class(
-            credentials=ga_credentials.AnonymousCredentials(), client_info=client_info,
+            credentials=ga_credentials.AnonymousCredentials(),
+            client_info=client_info,
         )
         prep.assert_called_once_with(client_info)
 
@@ -1376,7 +1589,8 @@ def test_client_with_default_client_info():
 @pytest.mark.asyncio
 async def test_transport_close_async():
     client = ServiceControllerAsyncClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport="grpc_asyncio",
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="grpc_asyncio",
     )
     with mock.patch.object(
         type(getattr(client.transport, "grpc_channel")), "close"
